Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSergey Sharybin <sergey.vfx@gmail.com>2013-09-20 17:22:45 +0400
committerSergey Sharybin <sergey.vfx@gmail.com>2013-09-20 17:22:45 +0400
commit97ee8b2b982064e10d5493f121d6ac64d039bc53 (patch)
tree71fa421f404d7eb0ddd736673fec6b9e4733440f /source/blender/makesdna/DNA_mesh_types.h
parent95bfe697045dd97d551e4957883e2dd4ad90003a (diff)
Mark Mesh->tface as DNA_DEPRECATED
It already had deprecated comment, but now it also uses compiler flag just to be sure no one uses this guy.
Diffstat (limited to 'source/blender/makesdna/DNA_mesh_types.h')
-rw-r--r--source/blender/makesdna/DNA_mesh_types.h2
1 files changed, 1 insertions, 1 deletions
diff --git a/source/blender/makesdna/DNA_mesh_types.h b/source/blender/makesdna/DNA_mesh_types.h
index e37d1368892..7cdb79232a9 100644
--- a/source/blender/makesdna/DNA_mesh_types.h
+++ b/source/blender/makesdna/DNA_mesh_types.h
@@ -79,7 +79,7 @@ typedef struct Mesh {
* real faces are now stored in nface.*/
struct MFace *mface; /* array of mesh object mode faces for tessellation */
struct MTFace *mtface; /* store tessellation face UV's and texture here */
- struct TFace *tface; /* depecrated, use mtface */
+ struct TFace *tface DNA_DEPRECATED; /* deprecated, use mtface */
struct MVert *mvert; /* array of verts */
struct MEdge *medge; /* array of edges */
struct MDeformVert *dvert; /* deformgroup vertices */